/*            - io1200.h -

   This file #defines the internal register addresses for AT90S1200.
   ONLY TO BE USED WITH AA90.

   Version: 1.10 [JB]

*/
#ifdef __IAR_SYSTEMS_ICC__
#error This compiler does not support the AT90S1200
#endif 
 
#ifdef __IAR_SYSTEMS_ASM  

#pragma language=extended

#if (((__TID__ >> 4) & 0x0F) != 0)
#error This file should only be included if the processor option is -v0
#endif

/* Include the SFR part if this file has not been included before,
 * OR this file is included by the assembler (SFRs must be defined in
 * each assembler module). AA90 has __TID__ bit 15 = 0. */
#if !defined(__IO1200_INCLUDED) || ((__TID__ >> 15) == 0)

/*==========================*/
/* Predefined SFR Addresses */
/*==========================*/

/* Analog Comparator Control and Status Register */
sfrb ACSR         = 0x08;

/* Input Pins, Port D */
sfrb PIND    = 0x10;

/* Data Direction Register, Port D */
sfrb DDRD    = 0x11;

/* Data Register, Port D */
sfrb PORTD    = 0x12;

/* Input Pins, Port B */
sfrb PINB    = 0x16;

/* Data Direction Register, Port B */
sfrb DDRB    = 0x17;

/* Data Register, Port B */
sfrb PORTB    = 0x18;

/* EEPROM Control Register */
sfrb EECR    = 0x1C;

/* EEPROM Data Register */
sfrb EEDR    = 0x1D;

/* EEPROM Address Register */
sfrb EEAR    = 0x1E;
sfrb EEARL   = 0x1E;

/* Watchdog Timer Control Register */
sfrb WDTCR    = 0x21;

/* Timer/Counter 0 */
sfrb TCNT0    = 0x32;

/* Timer/Counter 0 Control Register */
sfrb TCCR0    = 0x33;

/* MCU general Control Register */
sfrb MCUCR    = 0x35;

/* Timer/Counter Interrupt Flag register */
sfrb TIFR    = 0x38;

/* Timer/Counter Interrupt MaSK register */
sfrb TIMSK    = 0x39;

/* General Interrupt Flag Register */
sfrb GIFR = 0x3A;

/* General Interrupt MaSK register */
sfrb GIMSK    = 0x3B;

/* Status REGister */
sfrb SREG    = 0x3F;


#ifndef __IO1200_INCLUDED
#define __IO1200_INCLUDED

/* SFRs are local in assembler modules (so this file may need to be */
/* included in more than one module in the same source file), */
/* but #defines must only be made once per source file. */

/*==============================*/
/* Interrupt Vector Definitions */
/*==============================*/

/* NB! vectors are specified as byte addresses */

#define    RESET_vect           (0x00)
#define    INT0_vect            (0x02)
#define    TIMER0_OVF0_vect     (0x04)
#define    ANA_COMP_vect        (0x06)
 
/* Bit definitions for use with the IAR Assembler   
   The Register Bit names are represented by their bit number (0-7).
*/     
 
/* General Interrupt MaSK register */ 
#define    INT0    6
 
/* Timer/Counter Interrupt MaSK register */ 
#define    TOIE0   1
 
/* Timer/Counter Interrupt Flag register */                    
#define    TOV0    1
 
/* MCU general Control Register */ 
#define    SE      5
#define    SM      4
#define    ISC01   1
#define    ISC00   0
 
/* Timer/Counter 0 Control Register */
#define    CS02    2
#define    CS01    1
#define    CS00    0
                        
/* Watchdog Timer Control Register */
#define    WDE     3
#define    WDP2    2
#define    WDP1    1
#define    WDP0    0
 
/* EEPROM Control Register */
#define    EEWE    1
#define    EERE    0
 
/* Data Register, Port B */ 
#define    PB7     7
#define    PB6     6
#define    PB5     5
#define    PB4     4
#define    PB3     3
#define    PB2     2
#define    PB1     1
#define    PB0     0
 
/* Data Direction Register, Port B */
#define    DDB7    7
#define    DDB6    6
#define    DDB5    5
#define    DDB4    4
#define    DDB3    3
#define    DDB2    2
#define    DDB1    1
#define    DDB0    0
 
/* Input Pins, Port B */
#define    PINB7   7
#define    PINB6   6
#define    PINB5   5
#define    PINB4   4
#define    PINB3   3
#define    PINB2   2
#define    PINB1   1
#define    PINB0   0
 
/* Data Register, Port D */
#define    PD6     6
#define    PD5     5
#define    PD4     4
#define    PD3     3
#define    PD2     2
#define    PD1     1
#define    PD0     0
 
/* Data Direction Register, Port D */
#define    DDD6    6
#define    DDD5    5
#define    DDD4    4
#define    DDD3    3
#define    DDD2    2
#define    DDD1    1
#define    DDD0    0
 
/* Input Pins, Port D */
#define    PIND6   6
#define    PIND5   5
#define    PIND4   4
#define    PIND3   3
#define    PIND2   2
#define    PIND1   1
#define    PIND0   0
       
/* Analog Comparator Control and Status Register */ 
#define    ACD     7
#define    ACO     5
#define    ACI     4
#define    ACIE    3
#define    ACIS1   1
#define    ACIS0   0
       
/* Pointer definition   */ 
#define    ZL     R30
       
/* Contants */ 
#define    RAMEND    0x1F    ;Last On-Chip SRAM Location
#define    XRAMEND   0x0
#define    E2END     0x3F
#define    FLASHEND  0x03FF


#endif /* __IO1200_INCLUDED (define part) */
#endif /* __IO1200_INCLUDED (SFR part) */ 
#endif /* __IAR_SYSTEMS_ASM   (Bit definitions)*/ 
